@@ -3,7 +3,7 @@ package Net::ACME2::X::UnrecognizedKey;
 use strict;
 use warnings;
 
-use parent qw( Net::ACME2::X::Generic );
+use parent qw( Net::ACME2::X::Base );
 
 sub new {
     my ($class, $pem) = @_;
